@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.120 2009/04/28 20:29:17 hany Exp $
+ * $Id: rpmopen.c,v 1.122 2010/09/29 19:59:27 hany Exp $
  */
 
 #include <config.h>
@@ -30,7 +30,9 @@
 #include <rpm/rpmfi.h>
 #endif
 
+#ifndef HAVE_RPM_RPMLEGACY_H
 int readLead(FD_t fd, /*@out@*/struct rpmlead *lead);
+#endif
 #ifdef HAVE_RPM42
 typedef enum sigType_e {
     RPMSIGTYPE_HEADERSIG= 5     /*!< Header style signature */
@@ -1047,9 +1049,9 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
     int rc;
     Header h = NULL;
     Header s = NULL;
-    // XXX phanecak: readLead() in not available with rpm.org's rpm-4.6 and for now I have
-    // no idea what to do with that so for now I just skip it
-    //struct rpmlead lead;
+#ifndef HAVE_RPM_RPMLEGACY_H
+    struct rpmlead lead;
+#endif
     int isSource;
     char buffer[500];
     struct stat buf;
@@ -1127,83 +1129,74 @@ rpmOpen(char *nameRpm, rpmDirPtr dir, rpmSubdirPtr tree)
                     nameRpm, rc);
             Fclose(fd);
             return (NULL);
-    }
+     }
 
 
-    /* close the descriptor */
-    Fclose(fd);
-
-    /* XXX I do not know whether it is necessary to open the file twice */
-    /* open the file for reading */
-    fd = Fopen(buffer, "r.fdio");
-    if (fd == NULL || Ferror(fd)) {
-        fprintf(stderr, "Fopen of %s failed: %s\n", buffer, Fstrerror(fd));
+#ifdef HAVE_RPM_RPMLEGACY_H
+    // XXX  phanecak: for now I do not know how to read signatures with rpm.org 4.6 or later
+#else	// ifdef HAVE_RPM_RPMLEGACY_H
+    /* read the RPM signature */
+    if (readLead(fd, &lead)) {
+        fprintf(stderr, "readLead failed\n");
+        fdClose(fd);
         return (NULL);
     }
+    switch (lead.major) {
+        case 1:
+            fprintf(stderr, "no signature available (v1.0 RPM) in %s\n",
+                    nameRpm);
+            break;
+        default:
+#ifdef HAVE_RPM42
+            if (rpmReadSignature(fd, &s, lead.signature_type, NULL)) {
+#else
+            if (rpmReadSignature(fd, &s, lead.signature_type)) {
+#endif
+                fprintf(stderr, "rpmReadSignature failed\n");
+                fdClose(fd);
+                return (NULL);
+            }
+            if (!s) {
+                fprintf(stderr, "no signature available in %s\n", nameRpm);
+                fdClose(fd);
+                return (NULL);
+            }
+#if defined(WITH_GPG)
+            /* open temp file for writing */
+            sigtarget = xmlMalloc(30);
+            strcpy(sigtarget, "/tmp/rpm2html.date.XXXXXX");
+            sigtarget = mktemp(sigtarget);
+            ofd = Fopen(sigtarget, "w.ufdio");
+            if (ofd == NULL || Ferror(ofd)) {
+                fprintf(stderr, "Fopen of %s failed: %s\n", sigtarget,
+                        Fstrerror(ofd));
+                xmlFree(sigtarget);
+                sigtarget = NULL;
+            }
 
-    /* read the RPM signature */
-    // XXX phanecak: readLead() in not available with rpm.org's rpm-4.6 and for now I have
-    // no idea what to do with that so for now I just skip it
-//    if (readLead(fd, &lead)) {
-//        fprintf(stderr, "readLead failed\n");
-//        fdClose(fd);
-//        return (NULL);
-//    }
-//    switch (lead.major) {
-//        case 1:
-//            fprintf(stderr, "no signature available (v1.0 RPM) in %s\n",
-//                    nameRpm);
-//            break;
-//        default:
-//#ifdef HAVE_RPM42
-//            if (rpmReadSignature(fd, &s, lead.signature_type, NULL)) {
-//#else
-//            if (rpmReadSignature(fd, &s, lead.signature_type)) {
-//#endif
-//                fprintf(stderr, "rpmReadSignature failed\n");
-//                fdClose(fd);
-//                return (NULL);
-//            }
-//            if (!s) {
-//                fprintf(stderr, "no signature available in %s\n", nameRpm);
-//                fdClose(fd);
-//                return (NULL);
-//            }
-//#if defined(WITH_GPG)
-//            /* open temp file for writing */
-//            sigtarget = xmlMalloc(30);
-//            strcpy(sigtarget, "/tmp/rpm2html.date.XXXXXX");
-//            sigtarget = mktemp(sigtarget);
-//            ofd = Fopen(sigtarget, "w.ufdio");
-//            if (ofd == NULL || Ferror(ofd)) {
-//                fprintf(stderr, "Fopen of %s failed: %s\n", sigtarget,
-//                        Fstrerror(ofd));
-//                xmlFree(sigtarget);
-//                sigtarget = NULL;
-//            }
-//
-//            /* write the header and archive to a temp file */
-//            while ((count =
-//                    Fread(stbuffer, sizeof(stbuffer[0]), sizeof(stbuffer),
-//                          fd)) > 0) {
-//                if (Fwrite(stbuffer, sizeof(stbuffer[0]), count, ofd) < 0) {
-//                    fprintf(stderr, "%s: Fwrite failed: %s\n", sigtarget,
-//                            Fstrerror(ofd));
-//                    xmlFree(sigtarget);
-//                    sigtarget = NULL;
-//                }
-//            }
-//            if (count < 0) {
-//                fprintf(stderr, "%s: Fread failed: %s\n", buffer,
-//                        Fstrerror(fd));
-//                xmlFree(sigtarget);
-//                sigtarget = NULL;
-//            }
-//
-//            Fclose(ofd);
-//#endif
-//            break;
-//    }
+            /* write the header and archive to a temp file */
+            while ((count =
+                    Fread(stbuffer, sizeof(stbuffer[0]), sizeof(stbuffer),
+                          fd)) > 0) {
+                if (Fwrite(stbuffer, sizeof(stbuffer[0]), count, ofd) < 0) {
+                    fprintf(stderr, "%s: Fwrite failed: %s\n", sigtarget,
+                            Fstrerror(ofd));
+                    xmlFree(sigtarget);
+                    sigtarget = NULL;
+                }
+            }
+            if (count < 0) {
+                fprintf(stderr, "%s: Fread failed: %s\n", buffer,
+                        Fstrerror(fd));
+                xmlFree(sigtarget);
+                sigtarget = NULL;
+            }
+
+            Fclose(ofd);
+#endif
+            break;
+    }
+#endif	// ifdef HAVE_RPM_RPMLEGACY_H
 
     /* close the descriptor */
     Fclose(fd);
